==> xorp-0.1.tar.gz: xorp-0.1/bgp/route_queue.cc <==
// -*- c-basic-offset: 4; tab-width: 8; indent-tabs-mode: t -*-

// Copyright (c) 2001,2002 International Computer Science Institute
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software")
// to deal in the Software without restriction, subject to the conditions
// listed in the XORP LICENSE file. These conditions include: you must
// preserve this copyright notice, and you cannot mention the copyright
// holders in advertising related to the Software without their permission.
// The Software is provided WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED. This
// notice is a summary of the XORP LICENSE file; the license in that file is
// legally binding.

#ident "$XORP: xorp/bgp/route_queue.cc,v 1.1.1.1 2002/12/11 23:55:49 hodson Exp $"

#include "route_queue.hh"
#include "peer_handler.hh"

template<class A>
RouteQueueEntry<A>::
RouteQueueEntry<A>(const SubnetRoute<A>* queued_route, 
		    RouteQueueOp operation) 
{
    _op = operation;
    _route = new SubnetRoute<A>(*queued_route);
    _origin_peer = NULL;
}

template<class A>
RouteQueueEntry<A>::
RouteQueueEntry<A>(RouteQueueOp operation, const PeerHandler *origin_peer) 
{
    assert(operation == RTQUEUE_OP_PUSH);
    _op = operation;
    _route = NULL;
    //note: it is valid for origin_peer to be NULL.
    _origin_peer = origin_peer;
}

template<class A>
RouteQueueEntry<A>::~RouteQueueEntry<A>() {
    if (_route != NULL)
	delete _route;
}

template<class A>
string
RouteQueueEntry<A>::str() const {
    string s;
    switch(_op) {
    case RTQUEUE_OP_ADD:
	s = "RTQUEUE_OP_ADD";
	break;
    case RTQUEUE_OP_DELETE:
	s = "RTQUEUE_OP_DELETE";
	break;
    case RTQUEUE_OP_REPLACE_OLD:
	s = "RTQUEUE_OP_REPLACE_OLD";
	break;
    case RTQUEUE_OP_REPLACE_NEW:
	s = "RTQUEUE_OP_REPLACE_NEW";
	break;
    case RTQUEUE_OP_PUSH:
	s = "RTQUEUE_OP_PUSH";
	break;
    }
    if (_route != NULL)
	s += "\n" + _route->str();
    else
	s += "\n_route is NULL";
    if (_origin_peer != NULL)
	s += "\nOrigin Peer: " + _origin_peer->peername();
    else
	s += "\n_origin_peer is NULL";
    return s;
}
 
template class RouteQueueEntry<IPv4>;
template class RouteQueueEntry<IPv6>;

==> xorp-0.4.tar.gz: xorp-0.4/bgp/route_queue.cc <==
// -*- c-basic-offset: 4; tab-width: 8; indent-tabs-mode: t -*-

// Copyright (c) 2001-2003 International Computer Science Institute
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software")
// to deal in the Software without restriction, subject to the conditions
// listed in the XORP LICENSE file. These conditions include: you must
// preserve this copyright notice, and you cannot mention the copyright
// holders in advertising related to the Software without their permission.
// The Software is provided WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED. This
// notice is a summary of the XORP LICENSE file; the license in that file is
// legally binding.

#ident "$XORP: xorp/bgp/route_queue.cc,v 1.5 2003/03/10 23:20:03 hodson Exp $"

#include "route_queue.hh"
#include "peer_handler.hh"

template<class A>
string
RouteQueueEntry<A>::str() const {
    string s;
    switch(_op) {
    case RTQUEUE_OP_ADD:
	s = "RTQUEUE_OP_ADD";
	break;
    case RTQUEUE_OP_DELETE:
	s = "RTQUEUE_OP_DELETE";
	break;
    case RTQUEUE_OP_REPLACE_OLD:
	s = "RTQUEUE_OP_REPLACE_OLD";
	break;
    case RTQUEUE_OP_REPLACE_NEW:
	s = "RTQUEUE_OP_REPLACE_NEW";
	break;
    case RTQUEUE_OP_PUSH:
	s = "RTQUEUE_OP_PUSH";
	break;
    }
    if (_route_ref.route() != NULL)
	s += "\n" + _route_ref.route()->str();
    else
	s += "\n_route is NULL";
    if (_origin_peer != NULL)
	s += "\nOrigin Peer: " + _origin_peer->peername();
    else
	s += "\n_origin_peer is NULL";
    return s;
}
 
template class RouteQueueEntry<IPv4>;
template class RouteQueueEntry<IPv6>;
